@@ -7,7 +7,7 @@ use strict;
 use Padre::Util   ('_T');
 use Padre::Perl;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 # The plugin name to show in the Plugin Manager and menus
 sub plugin_name { 'Catalyst' }
@@ -260,7 +260,10 @@ sub menu_plugins {
     );
     
     # Return it and the label for our plug-in
-    return ( $self->plugin_name => $menu );   
+    return ( $self->plugin_name => $menu );  
+    
+    #TODO: add status bar comment for each menu entry.
+    # look into Padre::Wx::Menu and wxWidgets for $item->SetHelp('foo')
 }
 
 
@@ -304,7 +307,7 @@ sub _open_template {
     require File::Find;
     require Padre::Plugin::Catalyst::Util;
     
-    my $project_dir = Padre::Plugin::Catalyst::Util::get_document_base_dir();
+    my $project_dir = Padre::Plugin::Catalyst::Util::get_document_base_dir() || return;
     my $template_dir = File::Spec->catdir( $project_dir, 'root' );
     
     my @files;
@@ -352,7 +355,7 @@ sub on_update_script {
 
 	require File::Spec;
 	require Padre::Plugin::Catalyst::Util;
-    my $project_dir = Padre::Plugin::Catalyst::Util::get_document_base_dir();
+    my $project_dir = Padre::Plugin::Catalyst::Util::get_document_base_dir() || return;
 
 	my @dir = File::Spec->splitdir($project_dir);
 	my $project = $dir[-1];
@@ -382,7 +385,7 @@ sub on_start_server {
     
 	require File::Spec;
 	require Padre::Plugin::Catalyst::Util;
-    my $project_dir = Padre::Plugin::Catalyst::Util::get_document_base_dir();
+    my $project_dir = Padre::Plugin::Catalyst::Util::get_document_base_dir() || return;
 
 	my $server_filename = Padre::Plugin::Catalyst::Util::get_catalyst_project_name($project_dir);
 						
@@ -556,19 +559,29 @@ sub on_show_about {
 
 sub plugin_enable {
     my $self = shift;
+
     require Padre::Plugin::Catalyst::Panel;
     $self->{panel} = Padre::Plugin::Catalyst::Panel->new($self);
 
+    Padre::Current->main->bottom->show($self->{panel});
+    
+    # load Catalyst main menu
+    $self->editor_changed;
+
 # TODO: Please uncomment this to test the Catalyst side-panel
 #    require Padre::Plugin::Catalyst::Outline;
 #    $self->{outline} = Padre::Plugin::Catalyst::Outline->new($self);
+
 }
 
 sub panel { return shift->{panel} }
 
 sub plugin_disable {
     my $self = shift;
-    $self->panel->Destroy;
+#    $self->panel->Destroy;
+    Padre::Current->main->bottom->hide($self->{panel});
+    $self->on_stop_server;
+    
     
     # cleanup loaded classes
     require Class::Unload;
@@ -579,16 +592,52 @@ sub plugin_disable {
     Class::Unload->unload('Catalyst');
 }
 
+# FIXME: Padre does *NOT* seem to call this if a document is closed.
+sub editor_changed {
+    my $self = shift;
+    my $document = $self->main->current->document || return $self->enable(0);
+
+    #$document->{menu} = [] if (!defined($document->{menu})) or (ref($document->{menu}) ne 'ARRAY');
+    #$document->{menu} = [grep (!/^menu\.Catalyst$/,@{$document->{menu}}) ];
+
+    # when not inside a catalyst project, disable stuff
+    my $toggle = 0;
+    require Padre::Plugin::Catalyst::Util;
+    if (Padre::Plugin::Catalyst::Util::in_catalyst_project($document->filename)) {
+        
+        # enable Catalyst main menu
+        #push @{$document->{menu}}, 'menu.Catalyst';
+        $toggle = 1;
+    }
+    # enable/disable Catalyst panel and menu entries
+    $self->enable($toggle);
+}
+
+# this method is invoked when the active document
+# is **NOT** part of a Catalyst project
+sub enable {
+    my ($self, $toggle) = (@_);
+    my $is_server_on = (defined $self->{server} ? 1 : 0);
+    
+    # freeze menu entries
+    # FIXME: this isn't working during startup
+    require Padre::Plugin::Catalyst::Util;
+    Padre::Plugin::Catalyst::Util::toggle_menu_items($toggle, $is_server_on);
+
+    # freeze the panel
+    $self->panel->{button}->Enable($toggle);
+    unless ($is_server_on) {
+        $self->panel->{checkbox}->Enable($toggle);
+    }
+}
+
+
 42;
 __END__
 =head1 NAME
 
 Padre::Plugin::Catalyst - Catalyst helper interface for Padre
 
-=head1 VERSION
-
-Version 0.07
-
 =head1 SYNOPSIS
 
 	cpan install Padre::Plugin::Catalyst;
@@ -651,7 +700,7 @@ Shows a nice about box with this module's name and version, as well as your inst
 
 =head1 TRANSLATIONS
 
-This plugin has been translated to the folowing languages (alfabetic order):
+This plugin has been translated to the folowing languages (alphabetic order):
 
 =over 4
 
